@@ -1,19 +1,20 @@
-__version__ = "2.4"
+__version__ = "3.0"
 
+from .customtkinter_dialog import CTkDialog
 from .customtkinter_button import CTkButton
 from .customtkinter_slider import CTkSlider
 from .customtkinter_frame import CTkFrame
 from .customtkinter_progressbar import CTkProgressBar
 from .customtkinter_label import CTkLabel
 from .customtkinter_entry import CTkEntry
-from .customtkinter_dialog import CTkDialog
 from .customtkinter_checkbox import CTkCheckBox
 from .customtkinter_tk import CTk
 from .customtkinter_canvas import CTkCanvas
 from .customtkinter_toplevel import CTkToplevel
+from .customtkinter_settings import CTkSettings
 
 from .appearance_mode_tracker import AppearanceModeTracker
-from .customtkinter_color_manager import CTkColorManager
+from .customtkinter_theme_manager import CTkThemeManager
 
 from distutils.version import StrictVersion as Version
 import tkinter
@@ -58,24 +59,28 @@ def get_appearance_mode():
 
 
 def set_default_color_theme(color_string):
-    CTkColorManager.initialize_color_theme(color_string)
+    CTkThemeManager.load_theme(color_string)
 
 
-if sys.platform.startswith("win"):
-    from ctypes import windll, byref, create_string_buffer
+if not sys.platform == "darwin":
+    import warnings
+    warnings.simplefilter("ignore", category=UserWarning)
 
-    FR_PRIVATE = 0x10
-    FR_NOT_ENUM = 0x20
+    import pyglet.font
 
-
-    def loadfont(fontpath: str, private=True, enumerable=False):
-        pathbuf = create_string_buffer(bytes(fontpath, "utf-8"))
-        add_font_resource_ex = windll.gdi32.AddFontResourceExA
-        flags = (FR_PRIVATE if private else 0) | (FR_NOT_ENUM if not enumerable else 0)
-        num_fonts_added = add_font_resource_ex(byref(pathbuf), flags, 0)
-        return bool(num_fonts_added)
-
-
-    # load custom font for rendering circles on the tkinter.Canvas with antialiasing
+    # load text fonts and custom font with circle shapes for round corner rendering
     script_directory = os.path.dirname(os.path.abspath(__file__))
-    loadfont(os.path.join(script_directory, "assets", "canvas_shapes_font.otf"), private=True)
+    pyglet.font.add_file(os.path.join(script_directory, "assets", "CustomTkinter_shapes_font-fine.otf"))
+    pyglet.font.add_file(os.path.join(script_directory, "assets", "Roboto", "Roboto-Regular.ttf"))
+    pyglet.font.add_file(os.path.join(script_directory, "assets", "Roboto", "Roboto-Medium.ttf"))
+    CTkSettings.circle_font_is_ready = pyglet.font.have_font("CustomTkinter_shapes_font")
+
+    warnings.simplefilter("default")
+
+    # correct drawing method if font could not be loaded
+    if not CTkSettings.circle_font_is_ready:
+        if CTkSettings.preferred_drawing_method == "font_shapes":
+            sys.stderr.write("WARNING (customtkinter.CTkSettings): " +
+                             "Preferred drawing method 'font_shapes' can not be used because the font file could not be loaded.\n" +
+                             "Using 'circle_shapes' instead. The rendering quality will be very bad!")
+            CTkSettings.preferred_drawing_method = "circle_shapes"
